@@ -3,7 +3,6 @@ import time
 import sys
 import httpx
 import requests
-import mechanize
 import string
 import json as _json
 from httpx import AsyncClient
@@ -35,7 +34,7 @@ SOFTWARE.
 '''
 
 # Helper Functions
-def listtodict(lst):
+def _listtodict(lst):
     it = iter(lst)
     response = dict(zip(it, it))
     return response
@@ -65,7 +64,7 @@ def reversedns(host: str) -> str:
     api =  requests.get(f'https://api.hackertarget.com/reversedns/?q={realip}').text.strip(f'{realip} ')
     return api
 
-def scan(target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=False, api :bool=False) -> Union[tuple,None]:
+def scan(target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=False, api :bool=False, threads: int=100) -> Union[tuple,None]:
     '''Python Port Scanner Enumerate all Open Ports of Given Host:\n
     Use dev_mode = True,  if You want response in list.\n
     Use API = True if you are making api
@@ -84,11 +83,11 @@ def scan(target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=F
                 elif api:
                     lists.append(f'{port}/tcp | {socket.getservbyport(port)}')
                 else:
-                    print(f'{port}/tcp\t |   {socket.getservbyport(port)}\t|   open   |')
+                    print(f'{port}/tcp\t   |   {socket.getservbyport(port)}\t|   open   |')
             sock.close()
 
         def execute():
-            with ThreadPoolExecutor(max_workers=10000) as host:
+            with ThreadPoolExecutor(max_workers=threads) as host:
                 if isinstance(port, Iterable):
                     host.map(scan_port, port)
                     return 'Scan Finished.'
@@ -115,20 +114,15 @@ def scan(target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=F
         return sys.exit('Process Stopped Exiting: 1')
 
 def subenum(host: str, cli=False, no_ip=True) -> Union[list, dict, None]:
-    """Enumerate a list of subdomains for given host Asynchronously"""
+    """Enumerate a list of subdomains for given host"""
     try:
-        GLOBAL_LIST = []
+        DOMAINS = []
         api = requests.get(f"https://api.hackertarget.com/hostsearch/?q={host}")
         lines = api.text.split("\n")
         if '' in lines:
             lines.remove('')
         if cli:
-            cliresponse = []
-            for x in lines:
-                if no_ip:
-                    cliresponse.append(x.split(',')[0])
-                else:
-                    cliresponse.append(x.split(','))
+            cliresponse = [x.split(',')[0] if no_ip else x.split(',') for x in lines]
             for i,v in enumerate(cliresponse, start=1):
                 if no_ip:
                     print(f'{i}). {v}')
@@ -141,13 +135,11 @@ def subenum(host: str, cli=False, no_ip=True) -> Union[list, dict, None]:
                 for line in lines:
                     x = line.split(',')
                     for j in x:
-                        GLOBAL_LIST.append(j)
-                return listtodict(GLOBAL_LIST)
+                        DOMAINS.append(j)
+                return _listtodict(DOMAINS)
 
     except requests.ConnectionError:
         return 'Connection Lost: Retry Again'
-    except requests.ConnectTimeout:
-        return 'Taking too long! Exiting: 1'
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
@@ -173,35 +165,28 @@ def grab(host: str, schema='http://', cli=False) -> Union[dict, None]:
             return dict(api.headers)
     except requests.ConnectionError:
         return 'Connection Lost: Exiting...'
-    except requests.ConnectTimeout:
-        return 'Unable to Get Response'
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
 def whois(target: str) -> str:
     """ Whois Lookup for a Given Host """
-    browser = mechanize.Browser()
-    url = 'https://www.ipvoid.com/whois/'
-    browser.open(url)
-    browser.select_form(nr=0)
-    browser['host']=target
-    response = browser.submit().read()
-    # Scraping Content
-    soup = BeautifulSoup(response, 'html.parser')
-    result = soup.find('textarea').get_text()
-    return result
+    try:
+        response = requests.get(f"https://api.webeye.ml/whois/?q={target}").text
+        return response
+    except (requests.ConnectionError, requests.ConnectTimeout):
+        return 'Unable to get result'
+    except Exception:
+        print("something went wrong")
 
 def geoip(host: str, cli=False) -> Union[dict, None]:
     '''Geolocation Enumeration for a given host'''
     realip = socket.gethostbyname(host)
-    api= requests.get(f'http://ip-api.com/json/{realip}?fields=66846715').json()
+    api : dict = requests.get(f'http://ip-api.com/json/{realip}?fields=66846715').json()
     if not cli:
         return api
     else:
-        a = 0
-        for x,y in api.items():
-            a+=1
-            print(f'{a}). {x}: {y}')
+        for c,(k,v) in enumerate(api.items(), start=1):
+            print(f'{c}). {k}: {v}')
 
 def encode(text: str, rot: int=0):
     '''Encode text from ROT_1 - ROT_25
@@ -235,23 +220,18 @@ def decode(text: str, rot: int) -> str:
         rot = text.maketrans(_rot, letters)
         return text.translate(rot)
 
-def is_cloudflare(host: str, schema='http://', cli=False) -> Union[bool, None]:
-    '''Check For Cloudflare in a given host'''
+def enumerate_waf(host: str) -> Union[str, list, bool]:
+    '''Enumerate list of Firewall protecting host, False if not found...'''
     try:
-        target = requests.get(schema+host)
-        o = target.headers
-        if o["server"] == "cloudflare":
-            if cli:
-                print('Cloudflare Detected on: {}'.format(host));return
-            return True
-        else:
-            if cli:
-                print('Cloudflare Not Detected on: {}'.format(host));return
-            return False
+        target = requests.get(f"https://api.webeye.ml/waf/?q={host}")
+        socket.gethostbyname(host)
+        waf = target.json()['manufacturer'] if target.json()['waf'] else False
+        return (waf if waf else False)
+
+    except socket.gaierror:
+        return "Unable to connect with host"
     except requests.ConnectionError:
         return 'Connection Lost: Exiting...'
-    except requests.ConnectTimeout:
-        return 'Unable to Get Response'
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
@@ -266,8 +246,6 @@ def fetch_dns(host: str, cli=False) -> Union[None, list]:
             return result
     except requests.ConnectionError:
         return 'Connection Lost: Exiting...'
-    except requests.ConnectTimeout:
-        return 'Unable to Get Response'
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
@@ -278,8 +256,6 @@ def isitdown(host: str) -> dict:
         return response
     except requests.ConnectionError:
         return 'Connection Lost: Exiting...'
-    except requests.ConnectTimeout:
-        return 'Unable to Get Response'
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
@@ -360,7 +336,7 @@ class AsyncHelper:
             else:
                 return 'Enter IP of Host not URL'
 
-    async def scan(self, target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=False, api :bool=False) -> Union[list, None]:
+    async def scan(self, target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=False, api :bool=False, threads: int=100) -> Union[list, None]:
         '''Asynchronous Python Port Scanner Enumerate all Open Ports of Given Host:\n
         Use dev_mode = True,  if You want response in list.\n
         Use API = True if you are making api
@@ -379,11 +355,11 @@ class AsyncHelper:
                     elif api:
                         lists.append(f'OPEN_PORTS | {port}tcp/{socket.getservbyport(port)}')
                     else:
-                        print(f'{port}/tcp\t |   {socket.getservbyport(port)}\t|   open   |')
+                        print(f'{port}/tcp\t  |   {socket.getservbyport(port)}\t|   open   |')
                 sock.close()
 
             async def execute():
-                with ThreadPoolExecutor(max_workers=10000) as host:
+                with ThreadPoolExecutor(max_workers=threads) as host:
                     if isinstance(port, Iterable):
                         host.map(scan_port, port)
                         return 'Scan Finished.'
@@ -420,17 +396,12 @@ class AsyncHelper:
                 if '' in lines:
                     lines.remove('')
                 if cli:
-                    cliresponse = []
-                    for x in lines:
-                        if no_ip:
-                            cliresponse.append(x.split(',')[0])
-                        else:
-                            cliresponse.append(x.split(','))
+                    cliresponse = [x.split(',')[0] if no_ip else x.split(',') for x in lines]
                     for i,v in enumerate(cliresponse, start=1):
                         if no_ip:
-                            print(f'{i}). {v}')
+                            print(f'{i:02}). {v}')
                         else:
-                            print(f"{v[0].ljust(60,' ')} | {v[1].rjust(40,' ')}  << ({i})")
+                            print(f"{v[0].ljust(60,' ')} | {v[1].rjust(40,' ')}  << ({i:02})")
                 else:
                     if no_ip:
                         return list(line.split(',')[0] for line in lines)
@@ -439,7 +410,7 @@ class AsyncHelper:
                             x = line.split(',')
                             for j in x:
                                 RESPONSE.append(j)
-                        return listtodict(RESPONSE)
+                        return _listtodict(RESPONSE)
         except httpx.ConnectError:
             return 'Connection Lost: Retry Again'
         except httpx.ConnectTimeout:
@@ -485,19 +456,14 @@ class AsyncHelper:
         except KeyboardInterrupt:
             return 'Stopped, Exiting: 1'
 
-    async def whois(target: str) -> str:
+    async def whois(self, target: str) -> str:
         '''Whois Lookup of a Given Host'''
         try:
-            browser = mechanize.Browser()
-            url = 'https://www.ipvoid.com/whois/'
-            browser.open(url)
-            browser.select_form(nr=0)
-            browser['host']=target
-            response = browser.submit().read()
-            # Scraping Content
-            soup = BeautifulSoup(response, 'html.parser')
-            result = soup.find('textarea').get_text()
-            return result
+            async with AsyncClient() as session:
+                response = await session.get(f"https://api.webeye.ml/whois/?q={target}")
+                return response.text
+        except (httpx.ConnectError, httpx.ConnectTimeout):
+            print("Unable to get response")
         except Exception as e:
             print(e)
 
@@ -506,13 +472,12 @@ class AsyncHelper:
         try:
             async with AsyncClient() as session:
                 realip = socket.gethostbyname(host)
-                api= await session.get(f'http://ip-api.com/json/{realip}?fields=66846715')
-                result = api.json()
+                api = await session.get(f'http://ip-api.com/json/{realip}?fields=66846715')
+                result : dict = api.json()
                 if not cli:
                     return result
                 else:
-                    a = 0
-                    for x,y in result.items():
+                    for a, (x, y) in enumerate(result.items(), start=1):
                         a+=1
                         print(f'{a}). {x}: {y}')
         except httpx.ConnectError:
@@ -522,20 +487,17 @@ class AsyncHelper:
         except socket.error:
             return 'Something Went Wrong!!!'
 
-    async def is_cloudflare(self, host: str, schema='http://', cli=False) -> Union[bool, None]:
-        '''Check For Cloudflare in a given host asynchronously'''
+    async def enumerate_waf(self, host: str) -> Union[list, str, bool]:
+        '''Enumerate list of Firewall protecting host, False if not found.'''
         try:
             async with AsyncClient() as session:
-                target = await session.get(schema+host)
-                o = dict(target.headers)
-                if o["server"] == "cloudflare":
-                    if cli:
-                        print('Cloudflare Detected on: {}'.format(host));return
-                    return True
-                else:
-                    if cli:
-                        print('Cloudflare Not Detected on: {}'.format(host));return
-                    return False
+                target = await session.get(f"https://api.webeye.ml/waf/?q={host}")
+                socket.gethostbyname(host)
+                waf = target.json()['manufacturer'] if target.json()['waf'] else False
+                return (waf if waf else False)
+
+        except socket.gaierror:
+            return "Unable to connect with host"
         except httpx.ConnectError:
             return 'Connection Lost: Exiting...'
         except httpx.ConnectTimeout:
@@ -586,4 +548,4 @@ class AsyncHelper:
         except socket.error:
             return f'{socket.gethostbyname(host)} is Unreachable'
         except KeyboardInterrupt:
-            return sys.exit('Stopped, Exiting: 1')
+            return sys.exit('Stopped, Exiting: 1')
\ No newline at end of file
